@@ -33,7 +33,7 @@ def standardize_name(
 			x = x.strip()
 			x = _remove_alpha_func(s=x, replace_with=replace_with)
 		if camel_to_snake:
-			x = convert_camel_to_snake(x)
+			x = convert_camel_to_snake(x, remove_non_alphanumeric=remove_non_alphanumeric)
 		x = x.lower()
 	except Exception as e:
 		if ignore_errors:
